@@ -25,7 +25,6 @@ class DaikinWSConnection:
         return self._address
 
     async def connect(self):
-        logger.debug(f'Connecting to Daikin device {self._address}')
         self._client = await self._session.ws_connect(self.ws_address)
 
     async def close(self):
@@ -36,6 +35,9 @@ class DaikinWSConnection:
         if self._client is None:
             await self.connect()
 
+        if self._client.closed:
+            await self.connect()
+
         pkg: Request = Request(dest, payload)
         data = pkg.serialize()
         logger.debug(f"[OUT]: {dest} {data}")
