@@ -114,7 +114,7 @@ class AlthermaUnitController:
                     valid = conf['settable'] and conf['minValue'] <= value <= conf['maxValue']
                 else:
                     valid = True
-            if not valid:
+            if not valid and validate:
                 raise AlthermaException(
                     f'Invalid argument {value} for operation {operation} or operation is not settable.')
             payload = {
